==> zio-aws-ssmsap_3-6.20.149.1-sources.jar: zio/aws/ssmsap/model/AssociatedHost.scala <==
package zio.aws.ssmsap.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class AssociatedHost(
    hostname: Optional[String] = Optional.Absent,
    ec2InstanceId: Optional[String] = Optional.Absent,
    osVersion: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssmsap.model.AssociatedHost = {
    import AssociatedHost.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssmsap.model.AssociatedHost
      .builder()
      .optionallyWith(hostname.map(value => value: java.lang.String))(
        _.hostname
      )
      .optionallyWith(ec2InstanceId.map(value => value: java.lang.String))(
        _.ec2InstanceId
      )
      .optionallyWith(osVersion.map(value => value: java.lang.String))(
        _.osVersion
      )
      .build()
  }
  def asReadOnly: zio.aws.ssmsap.model.AssociatedHost.ReadOnly =
    zio.aws.ssmsap.model.AssociatedHost.wrap(buildAwsValue())
}
object AssociatedHost {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssmsap.model.AssociatedHost
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ssmsap.model.AssociatedHost =
      zio.aws.ssmsap.model.AssociatedHost(
        hostname.map(value => value),
        ec2InstanceId.map(value => value),
        osVersion.map(value => value)
      )
    def hostname: Optional[String]
    def ec2InstanceId: Optional[String]
    def osVersion: Optional[String]
    def getHostname: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("hostname", hostname)
    def getEc2InstanceId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("ec2InstanceId", ec2InstanceId)
    def getOsVersion: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("osVersion", osVersion)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssmsap.model.AssociatedHost
  ) extends zio.aws.ssmsap.model.AssociatedHost.ReadOnly {
    override val hostname: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.hostname())
      .map(value => value: String)
    override val ec2InstanceId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.ec2InstanceId())
      .map(value => value: String)
    override val osVersion: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.osVersion())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssmsap.model.AssociatedHost
  ): zio.aws.ssmsap.model.AssociatedHost.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ssmsap_3-7.21.15.5-sources.jar: zio/aws/ssmsap/model/AssociatedHost.scala <==
package zio.aws.ssmsap.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class AssociatedHost(
    hostname: Optional[String] = Optional.Absent,
    ec2InstanceId: Optional[String] = Optional.Absent,
    ipAddresses: Optional[Iterable[zio.aws.ssmsap.model.IpAddressMember]] =
      Optional.Absent,
    osVersion: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssmsap.model.AssociatedHost = {
    import AssociatedHost.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssmsap.model.AssociatedHost
      .builder()
      .optionallyWith(hostname.map(value => value: java.lang.String))(
        _.hostname
      )
      .optionallyWith(ec2InstanceId.map(value => value: java.lang.String))(
        _.ec2InstanceId
      )
      .optionallyWith(
        ipAddresses.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.ipAddresses)
      .optionallyWith(osVersion.map(value => value: java.lang.String))(
        _.osVersion
      )
      .build()
  }
  def asReadOnly: zio.aws.ssmsap.model.AssociatedHost.ReadOnly =
    zio.aws.ssmsap.model.AssociatedHost.wrap(buildAwsValue())
}
object AssociatedHost {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssmsap.model.AssociatedHost
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ssmsap.model.AssociatedHost =
      zio.aws.ssmsap.model.AssociatedHost(
        hostname.map(value => value),
        ec2InstanceId.map(value => value),
        ipAddresses.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        osVersion.map(value => value)
      )
    def hostname: Optional[String]
    def ec2InstanceId: Optional[String]
    def ipAddresses
        : Optional[List[zio.aws.ssmsap.model.IpAddressMember.ReadOnly]]
    def osVersion: Optional[String]
    def getHostname: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("hostname", hostname)
    def getEc2InstanceId: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("ec2InstanceId", ec2InstanceId)
    def getIpAddresses: ZIO[Any, AwsError, List[
      zio.aws.ssmsap.model.IpAddressMember.ReadOnly
    ]] = AwsError.unwrapOptionField("ipAddresses", ipAddresses)
    def getOsVersion: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("osVersion", osVersion)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssmsap.model.AssociatedHost
  ) extends zio.aws.ssmsap.model.AssociatedHost.ReadOnly {
    override val hostname: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.hostname())
      .map(value => value: String)
    override val ec2InstanceId: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.ec2InstanceId())
      .map(value => value: String)
    override val ipAddresses
        : Optional[List[zio.aws.ssmsap.model.IpAddressMember.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.ipAddresses())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.ssmsap.model.IpAddressMember.wrap(item)
          }.toList
        )
    override val osVersion: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.osVersion())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssmsap.model.AssociatedHost
  ): zio.aws.ssmsap.model.AssociatedHost.ReadOnly = new Wrapper(impl)
}
